API docs for “spamfighter.core.firewall.MessageFirewall”

# Class s.c.f.MessageFirewall(object):

Part of spamfighter.core.firewall View Source View In Hierarchy

"Черный ящик" анализа сообщений по правилам, построенный по мотивам работы firewall.

Instance Variables | rules | текущие правила анализа (текстовое представление) (type: `str` )
| compiled | скомпилированные правила анализа (type: `list(``FirewallStatement``)` )

Method | __init__ | Конструктор.
Method | __getstate__ | Undocumented
Method | __setstate__ | Undocumented
Method | getRules | Получить текущие правила firewall'а.
Method | setRules | Установить новые правила анализа.
Method | syntaxCheck | Осуществить синтаксическую проверку текста правил.
Method | parse | Распарсить текстовую запись правил файрвола и вернуть
Method | compile | Компиляция распарсенного представления правил в
Method | analyze | Анализировать входящие сообщение и вернуть результат анализа.

def __init__(self, rules=None): (source)
Конструктор.

Parameters | rules | правила анализа (type: `str` )

def __getstate__(self): (source)
Undocumented
def __setstate__(self, state): (source)
Undocumented
def getRules(self): (source)
Получить текущие правила firewall'а.

Returns | текстовое представление текущих правил. (type: `str` )

def setRules(self, rules): (source)
Установить новые правила анализа.

Parameters | rules | правила анализа (type: `str` )

def syntaxCheck(self, rules): (source)
Осуществить синтаксическую проверку текста правил.

Parameters | rules | правила анализа (type: `str` )
Raises | SyntaxError | если записи правил имеются синтаксические ошибки

def parse(self, rules): (source)
Распарсить текстовую запись правил файрвола и вернуть синтаксически корректное внутреннее представление.

Parameters | rules | правила файрвола (в виде текста) (type: `str` )
Returns | распознанное представление (type: `list` )
Raises | SyntaxError | если записи правил имеются синтаксические ошибки

def compile(self, parsed_rules): (source)
Компиляция распарсенного представления правил в набор объектов правил файрвола.

Parameters | parsed_rules | распознанное представление правил (type: `list` )

def analyze(self, message, domain, debug=False, logCallback=None): (source)
Анализировать входящие сообщение и вернуть результат анализа.

Parameters | message | анализируемое сообщение (type: `IMessage` )
| domain | текущий домен (type: `IDomain` )
| debug | включить отладочный режим? (type: `bool` )
| logCallback | функция, которая получит лог прохождения сообщения через firewall в отладочном режиме, прототип функции: С{logCallback(log)}
Returns | результат анализа (type: `twisted.internet.defer.Deferred` )